
#include <iostream>

#include "GWt_LigneFaisceau.h"
#include "GWt_drift.h"
#include "GWt_rfgun.h"
#include "GWt_cell.h"
#include "GWt_soleno.h"
#include "GWt_bend.h"
#include "mixedTools.h"

#include <Wt/WComboBox>
#include <Wt/WVBoxLayout>

GWt_LigneFaisceau::GWt_LigneFaisceau(PspaApplication* ps) : pspa_(ps), nObjets_(NULL)
{
  beamLayout_ = new WHBoxLayout();
  decorationStyle().setBackgroundColor (WColor("orange")); 
  setLayout(beamLayout_);


  int nElts= nomdElements::getNumberOfElements(); 
  nObjets_= new Compteur[nElts];
  for(int k = 0; k < nElts; k++) {
    typedElement eType= (typedElement)k;
    acceptDrops(nomdElements::getImageFromType(eType));
  }

  // ajouter cette image ???
  // acceptDrops("icons/final.jpg");

}
 
string GWt_LigneFaisceau::createLabel(nomdElements el,int n)
{
  string str;
  if(n < 10) {
    str= el.getElementLabel()+"0"+mixedTools::intToString(n);
  } else {
    str= el.getElementLabel()+mixedTools::intToString(n);
  }
  return str;
}

void GWt_LigneFaisceau::dropEvent(WDropEvent evt)
{
  nomdElements e(evt.mimeType());
  typedElement eType = e.getElementType();
  cout << "GWt_LigneFaisceau::dropEvent " << evt.mimeType() << " " << eType << endl;
  if(eType == inconnu) {
    cout << "GWt_LigneFaisceau::element type " << eType << " inconnu " << endl;
    return;
  }

  pspa_->addConsoleMessage(e.getElementName());
  abstractElement* ptr = pspa_->getDataManager()->addElement(eType);
  ptr->setLabel(createLabel(e,nObjets_[eType].incr()));
  cout << " je vais ajouter l'element  " << ptr->getName().getElementName() << " de type " << ptr->getName().getElementType() << endl;
  //  GWt_abstractElement* gw = GWt_abstractElement::ajoute(pspa_,ptr,evt.mimeType());
  GWt_abstractElement* gw = GWt_abstractElement::ajoute(pspa_,ptr);
  if(gw == NULL) return;

  WContainerWidget* wc = NULL;  
  gw->updateLabelWidget();
  wc= gw->getWidget();
  beamLayout_->addWidget(wc);
  pspa_->updateSelections();

  //////////////////////////////////////////////////////////////////

  // pourVoir
  int nElts= pspa_->getDataManager()->beamLineSize();
  cout << "GWt_LigneFaisceau:: nElts= " << nElts << endl;
  unsigned int k;
  for(k = 0; k < (unsigned)nElts; k++) {
    abstractElement* ptr= pspa_->getDataManager()->getCollection()->getElementPointer(k);
    string label= ptr->getLabel();
    cout << "GWt_LigneFaisceau:: " << label << " dans la liste" << endl;
  }
  
}
    
void GWt_LigneFaisceau::restoreElementCollection()
{
  beamLayout_->clear();

  delete[] nObjets_;
  //  nomdElements ee;
  int nElements= nomdElements ::getNumberOfElements(); 
  nObjets_= new Compteur[nElements];

  int nbElem = pspa_->getDataManager()->beamLineSize();
  unsigned int k;
  for(k = 0; k < (unsigned)nbElem; k++) 
    {     
      abstractElement* ptr = pspa_->getDataManager()->getCollection()->getElementPointer(k);
      GWt_abstractElement* gw = GWt_abstractElement::ajoute(pspa_,ptr);
      if(gw == NULL) {
	cerr << "GWt_LigneFaisceau::restaure element type " << ptr->getName().getElementName() << " inconnu " << endl;
      }
      
      gw->updateLabelWidget();
      // nObjets_[eType].incr();
      nObjets_[ptr->getName().getElementType()].incr();
      beamLayout_->addWidget(gw->getWidget());
    } 

  pspa_->updateSelections();
}
