
#include "GWt_abstractElement.h"
#include "GWt_rfgun.h"
#include "GWt_drift.h"
#include "GWt_cell.h"
#include "GWt_bend.h"
#include "GWt_soleno.h"

#include "mixedTools.h"
#include "nomdElements.h"

#include <Wt/WText>

//GWt_abstractElement::GWt_abstractElement(PspaApplication* ps,abstractElement* elem,string image)
GWt_abstractElement::GWt_abstractElement(PspaApplication* ps,abstractElement* elem)
{
  pspa_ = ps;
  element_ = elem;

  dropped_ = new WPushButton();
  dropped_->setIcon(element_->getName().getElementImage());
  dropped_->setMaximumSize(50,50);
  dropped_->clicked().connect(this,&GWt_abstractElement::clicked);
  dropped_->doubleClicked().connect(this,&GWt_abstractElement::doubleClicked);
  
  wc_ = new WContainerWidget();
  wc_->addWidget(dropped_);
  wc_->addWidget(new WBreak());
}

void GWt_abstractElement::updateLabelWidget()
{
  string str = element_->getLabel();
  WText *item = new WText(str);
  wc_->addWidget(item);
}

void GWt_abstractElement::clicked()
{
  cout << "mouse key was clicked on this widget" << endl;
  dialog_->show();
}

void GWt_abstractElement::doubleClicked()
{
  cout << "mouse key was double clicked on this widget" << endl;
  message_= new WDialog("Question");
  message_->setClosable(true);
  new WText("Are you sure you want to delete the selected item?",message_->contents());
  new WBreak(message_->contents());
  WPushButton *yes= new WPushButton("Yes",message_->contents());
  yes->clicked().connect(message_,&Wt::WDialog::accept);
  message_->finished().connect(this,&GWt_abstractElement::messageDone);
  message_->show();
}

void GWt_abstractElement::messageDone()
{
  if (message_->result() == WDialog::Accepted) {
    wc_->clear();
    string label= element_->getLabel();
    cout << "GWt_abstractElement:: " << label << " a été supprimé" << endl;
    pspa_->getDataManager()->getCollection()->eraseElement(label);
    pspa_->updateSelections();
  }
  delete message_;
}

WPushButton* GWt_abstractElement::getButton() { 
  return dropped_;
}

WContainerWidget* GWt_abstractElement::getWidget() {
  return wc_;
}

GWt_abstractElement* GWt_abstractElement::ajoute(PspaApplication* ps,abstractElement* ptr)
{
  typedElement eType = ptr->getName().getElementType();

  switch (  eType ) {
  case RFgun : return new GWt_rfgun(ps,ptr);
  case drift : return new GWt_drift(ps,ptr);
  case cell  : return new GWt_cell(ps,ptr);
  case bend  : return new GWt_bend(ps,ptr);
  case soleno  : return new GWt_soleno(ps,ptr);
  case inconnu : return NULL;
  default : return NULL;
  }
}

