
#include <iostream>
#include <cstring>
#include "nomdElements.h"

typedElement nomdElements::fromImage(std::string s)
{
  if( strstr(s.c_str(),"rfgun") ) return RFgun;
  else if( strstr(s.c_str(),"drift") ) return drift;
  else if( strstr(s.c_str(),"cell") )  return cell;
  else if( strstr(s.c_str(),"bend") ) return bend;
  else if( strstr(s.c_str(),"lens") ) return soleno;
  return inconnu;
}

std::string nomdElements::toName(typedElement eType)
{
  switch(eType) {
  case RFgun : return "RF GUN"; break;
  case drift : return "DRIFT"; break;
  case cell : return "CELL"; break;
  case bend : return "BENDING MAGNET"; break;
  case soleno : return "SOLENOID"; break;
  default : return "UNKNOWN";
  }
}

std::string nomdElements::toImage(typedElement eType)
{
  switch(eType) {
  case RFgun : return string("icons/rfgun.jpg"); break;
  case drift : return string("icons/drift.jpg"); break;
  case cell : return string("icons/cell.jpg"); break;
  case bend : return string("icons/bend.jpg"); break;
  case soleno :  return string("icons/lens.jpg"); break;
  default : return string("");
  }
}

std::string nomdElements::toLabel(typedElement eType)
{
  switch(eType) {
  case RFgun : return "RFgun";
  case drift :  return "drift";
  case cell :  return "cell";
  case bend :  return "bend";
  case soleno :   return "solnd";
  default : return string("");
  }
}


nomdElements::nomdElements() 
{
  e_= fromImage("");
  eName_ = toName(e_);
  eImg_ = toImage(e_);
  eLabel_ = toLabel(e_);
}

nomdElements::nomdElements(nomdElements& ne)
{
  e_= ne.e_;
  eName_ = ne.eName_;
  eImg_ = ne.eImg_;
  eLabel_ = ne.eLabel_;
}

nomdElements::nomdElements(const nomdElements& ne)
{
  e_= ne.e_;
  eName_ = ne.eName_;
  eImg_ = ne.eImg_;
  eLabel_ = ne.eLabel_;
}
 

nomdElements::nomdElements(const std::string& s) 
{
  e_= fromImage(s);
  eName_ = toName(e_);
  eImg_ = toImage(e_);
  eLabel_ = toLabel(e_);
}

nomdElements::nomdElements(typedElement& eType) 
{
  e_= eType;
  eName_ = toName(e_);
  eImg_ = toImage(e_);
  eLabel_ = toLabel(e_);
}

int nomdElements::getNumberOfElements() {
  return inconnu;
}

std::string nomdElements::getImageFromType( typedElement tp)
{
  return toImage(tp);
}

std::string nomdElements::getLabelFromType(typedElement tp)
{
  return toLabel(tp);
}




typedElement nomdElements::getElementType() const {
  return e_;
}

std::string nomdElements::getElementName() const {
  return eName_;
}

std::string nomdElements::getElementImage() const {
  return eImg_;
}

std::string nomdElements::getElementLabel() const
{
  return eLabel_;
}




// operators
  
nomdElements& nomdElements::operator= (const nomdElements& ne)
{
  e_= ne.e_;
  eName_ = ne.eName_;
  eImg_ = ne.eImg_;
  eLabel_ = ne.eLabel_;
}
